import React from 'react';
import { Scene, Nullable, EngineOptions, SceneOptions, EventState, Camera } from '@babylonjs/core';
export * from './engine';
export * from './scene';
export declare type BabylonjsProps = {
    antialias?: boolean;
    engineOptions?: EngineOptions;
    adaptToDeviceRatio?: boolean;
    renderChildrenWhenReady?: boolean;
    sceneOptions?: SceneOptions;
    onSceneReady: (scene: Scene) => void;
    onRender?: (scene: Scene) => void;
    id: string;
    children?: React.ReactNode;
};
export declare type OnFrameRenderFn = (eventData: Scene, eventState: EventState) => void;
/**
 * Register a callback for before the scene renders.
 *
 * @param callback called using onBeforeRender functionality of scene
 * @param mask the mask used to filter observers
 * @param insertFirst if true will be inserted at first position, if false (default) will be last position.
 * @param callOnce only call the callback once
 */
export declare const useBeforeRender: (callback: OnFrameRenderFn, mask?: number | undefined, insertFirst?: boolean | undefined, callOnce?: boolean | undefined) => void;
/**
 * Register a callback for after the scene renders.
 *
 * @param callback called using onBeforeRender functionality of scene
 * @param mask the mask used to filter observers
 * @param insertFirst if true will be inserted at first position, if false (default) will be last position.
 * @param callOnce only call the callback once
 */
export declare const useAfterRender: (callback: OnFrameRenderFn, mask?: number | undefined, insertFirst?: boolean | undefined, callOnce?: boolean | undefined) => void;
/**
 * Handles creating a camera and attaching/disposing.
 *
 * @param createCameraFn function that creates and returns a camera
 * @param autoAttach Attach the input controls (default true)
 * @param noPreventDefault Events caught by controls should call prevent default
 */
export declare const useCamera: <T extends Camera>(createCameraFn: (scene: Scene) => T, autoAttach?: boolean, noPreventDefault?: boolean) => Nullable<T>;
declare const _default: (props: BabylonjsProps) => JSX.Element;
export default _default;
